/**
 * @(#)Main.java
 *
 * @history
 * @modification 99/07/10, Bernhard Fischer
 *  coding
 */

import java.awt.*;
import java.awt.Button;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;

import java.util.StringTokenizer;

import gui.GuiSerializer;
import gui.GuiRegistry;


/**
 * This class implements the an example application for the GUI serialization.
 *
 * @version 99/07/10
 * @author Bernhard Fischer
 */
public class Main extends Frame {
	protected Panel personPanel;
	protected Dialog showDialog; 
    protected GuiSerializer guiSerializer;
    
    /**
     * Create the example application.
     */
	public Main() {
	    super("Example 1");
	    try {
	        personPanel = (Panel)  GuiSerializer.read("PersonPanel.ser");
	        print(personPanel);
	        showDialog  = (Dialog) GuiSerializer.read("ShowDialog.ser");
	        print(showDialog);
	    }
	    catch (Exception e) {
	        e.printStackTrace();
	    }
	    final GuiRegistry regPersonPanel = new GuiRegistry(personPanel);
	    final GuiRegistry regShowDialog  = new GuiRegistry(showDialog);
	    Button show = (Button) regPersonPanel.find("btnShow");
	    show.addActionListener(new ActionListener() {
	            public void actionPerformed(ActionEvent e) {
	                System.out.println("show dialog");
	                TextField lastName  = (TextField) regPersonPanel.find("txtLastName");
	                TextField firstName = (TextField) regPersonPanel.find("txtFirstName");
	                TextField fullName  = (TextField) regShowDialog.find("txtFullName");
	                fullName.setText(firstName.getText() + " " + lastName.getText());
	                // Showing the serialized nonmodal dialog in modal mode does throw
	                // a NullPointerException in method sun.awt.windows.WDialogPeer.show().
	                // showDialog.setModal(true);
	                showDialog.setVisible(true);
	            }
	    });
	    add(personPanel);
	    final Button ok = (Button) regShowDialog.find("btnClose");
	    ok.addActionListener(new ActionListener() {
	            public void actionPerformed(ActionEvent e) {
	                showDialog.setVisible(false);
	            }
	    });
	    addWindowListener(new WindowAdapter() {
	            public void windowClosing(WindowEvent event) {
			        Object object = event.getSource();
			        if (object == Main.this)
				        Main.this.setVisible(false);;
		        }
		});
	    pack();
	    setVisible(true);
    }
	
	/**
	 * Print a component with all subcomponents.
	 *
	 * @param c root component
	 */
	public void print(Component c) {
	    print(c, 0);
	}
	
	/**
	 * Print a component with all subcomponents.
	 *
	 * @param c root component
	 * @param level indentation level
	 */
	protected void print(Component c, int level) {
	    for (int i = 0; i < level; i++)
	        System.out.print("  ");
	    System.out.println(c);
	    if (c instanceof Container) {
	        Component[] cs = ((Container)c).getComponents();
	        for (int i = 0; i < cs.length; i++)
	            print(cs[i], level + 1);
	    }
	}

    /**
     * The application entry point, called by the VM.
     *
     * @param args  command line parameters
     */
    public static void main(String[] args) {
        new Main();
    }
}