/**
 * @(#)GuiRegistry.java
 *
 * @history
 * @modification 99/07/10, Bernhard Fischer
 *  coding
 */

package gui;

import java.awt.Component;
import java.awt.Container;

import java.io.OutputStream;
import java.io.ObjectOutputStream;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.StreamCorruptedException;
import java.io.OptionalDataException;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.File;
import java.io.FileNotFoundException;

import java.util.Enumeration;
import java.util.StringTokenizer;
import java.util.Vector;

import gui.GuiInvisible;


/**
 * This class registers a root component and provides access to it's subcomponents
 * by their name property.
 *
 * @version 99/07/10
 * @author Bernhard Fischer
 */
public class GuiRegistry {
    
	protected Component root;

    /**
     * Creates a registry and register component root.
     *
     * @param root  the root component
     */
	public GuiRegistry(Component root) {
		this.root = root;
	}

    /**
     * Retrieves a subcomponent by it's name property or class name value.
     *
     * @param names value of the subcomponents name property or class name. For qualification
     *      this value may be preceeded by the values of parent components separated by dots.
     * @return the first matching component
     * @exception NullPointerException when no component matches
     */
	public Component find(String names) {
		Component[] components = lookup(root, names, true);
		if (components == null || components.length == 0)
		    throw new NullPointerException();
		return components[0];
	}


	protected Component[] lookup(Component root, String names, boolean firstOnly) {
	    if (root == null || names == null)
	        return null;
	    StringTokenizer st = new StringTokenizer(names, ".");
	    String[] nameArray = new String[st.countTokens()];
	    for (int i = 0; st.hasMoreTokens(); i++)
	        nameArray[i] = st.nextToken();
	    if (nameArray.length == 0)
	        return null;
	    Vector components = new Vector();
	    lookup(components, root, nameArray, 0, firstOnly);
	    Component[] result = new Component[components.size()];
	    Enumeration ce = components.elements();
	    for (int i = 0; ce.hasMoreElements(); i++)
	        result[i] = (Component)ce.nextElement();
	    return result;
	}


	protected void lookup(Vector result, Component root, String[] names, int offset, boolean firstOnly) {
	    boolean found = false;
	    if (names[offset].equals(root.getName())) {
	        found = true;
	    } else {
	        String className = root.getClass().getName();
	        if (className.endsWith("." + names[offset]))
	            found = true;
	    }
	    if (found && offset + 1 == names.length) {
	        result.addElement(root);
	        if (firstOnly)
	            return;
	    }
	    if (root instanceof Container) {
	        Component[] cs = ((Container)root).getComponents();
	        if (found) {
	            for (int i = 0; i < cs.length; i++) {
	                lookup(result, cs[i], names, offset + 1, firstOnly);
	                if (firstOnly && result.size() > 0)
	                    return;
	            }
	        }
	        for (int i = 0; i < cs.length; i++) {
	            lookup(result, cs[i], names, offset, firstOnly);
	            if (firstOnly && result.size() > 0)
	                return;
	        }
	    }
	    return;
	}
}
