/**
 * @(#)GuiSerializer.java
 *
 * This file belongs to the Tools and Materials Application Framework for Java.
 * Read file $JWAM/doc/Copyright about permission to use. This file may only be used
 * and distributed together with the copyright file.
 *
 * @history
 * @modification v0.10, 97/06/13, Martin Lippert
 *  Coding
 * @modification v0.11, 97/06/20, Martin Lippert
 *  Package umbenannt in development.gui
 * @modification v0.12, 97/08/01, Martin Lippert
 *  Benennung geaendert, BeanInfo eingepflegt
 * @modification v0.13, 98/04/02, Martin Lippert
 *  Package-Umbenennung nach JWAM1.1 eingepflegt, NonVisible-Typ eingepflegt
 * @modification 99/07/10, Bernhard Fischer
 *  Implementation of JWAM class Importer added.
 */
 
package gui;

import java.awt.Component;
import java.awt.Container;

import java.io.OutputStream;
import java.io.ObjectOutputStream;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.StreamCorruptedException;
import java.io.OptionalDataException;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.File;
import java.io.FileNotFoundException;

import java.util.StringTokenizer;

import gui.GuiInvisible;


/**
 * The class GuiSerializer provide methods to serialize and deserialize components.
 *
 * @version 99/07/10
 * @author Martin Lippert
 */
public class GuiSerializer
{
	private GuiSerializer() {
	}

	/**
	 * Serializes a component and writes it to the output stream.
	 *
	 * @param ostream   the stream to which the component is written
	 * @param component the component to be serialized
	 * @exception IOException when serialization fails
	 */
	public static void write(OutputStream ostream, Component component) throws IOException {
		ObjectOutputStream oostream = new ObjectOutputStream(ostream);
		try {
			oostream.writeObject(component);
		} finally {
			oostream.close();
		}
  	}

	/**
	 * Serializes a component and writes it to a file.
	 *
	 * @param pathname  the name of the file to which the component is written
	 * @param component the component to be serialized
	 * @exception IOException when serialization fails
	 */
  	public static void write(String pathname, Component component) throws IOException {
        FileOutputStream ostream = null;
  	    try {
            ostream = new FileOutputStream(pathname);
  	        write(ostream, component);
  	    } finally {
		    ostream.close();
        }
    }
  	
	/**
	 * Reads a component from an input stream and deserializes it.
	 *
	 * @param istream   the input stream from where the component is read
	 * @return the deserialized component
	 * @exception IOException when deserialization fails
	 * @exception StreamCorruptedException when deserialization fails
	 * @exception ClassNotFoundException when the deserialized class can't be loaded
	 * @exception OptionalDataException when deserialization fails
	 */
  	public static Component read(InputStream istream) throws IOException,
  	                StreamCorruptedException, ClassNotFoundException, OptionalDataException {
		ObjectInputStream oistream = new ObjectInputStream(istream);
		Object object = null;
		try {
			object = oistream.readObject();
		} finally {
			oistream.close();
		}
		Component component = (Component)object;
		GuiRegistry guiRegistry = new GuiRegistry(component);
		Component guiSerializer = guiRegistry.find("GuiSerializerButton");
		if (guiSerializer != null) {
		    guiSerializer.setVisible(false);
		}
		return component;
  	}
	
	/**
	 * Reads a component from a file and deserializes it.
	 *
	 * @param pathname  the name of the file from which the component is read
	 * @return the deserialized component
	 * @exception IOException when deserialization fails
	 * @exception StreamCorruptedException when deserialization fails
	 * @exception ClassNotFoundException when the deserialized class can't be loaded
	 * @exception OptionalDataException when deserialization fails
	 */
  	public static Component read(String pathname) throws FileNotFoundException,
  	            IOException, ClassNotFoundException {
        FileInputStream istream = null;
        Component component = null;
        istream = new FileInputStream(pathname);
        try {
            component = read(istream);
        } finally {
            istream.close();
        }
        return component;
    }
}
