/**
 * @(#)GuiSerializerButton.java
 *
 * This file belongs to the Tools and Materials Application Framework for Java.
 * Read file $JWAM/doc/Copyright about permission to use. This file may only be used
 * and distributed together with the copyright file.
 *
 * @history
 * @modification v0.10, 97/06/13, Martin Lippert
 *  Coding
 * @modification v0.11, 97/06/20, Martin Lippert
 *  Package umbenannt in development.gui
 * @modification v0.12, 97/08/01, Martin Lippert
 *  Benennung geaendert, BeanInfo eingepflegt
 * @modification v0.13, 98/04/02, Martin Lippert
 *  Package-Umbenennung nach JWAM1.1 eingepflegt, NonVisible-Typ eingepflegt
 * @modification 99/07/10, Bernhard Fischer
 *  comments added
 */

package gui;

import java.awt.Button;
import java.awt.Container;
import java.awt.FileDialog;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import gui.GuiInvisible;


/**
 * This class creates a button which serializes the parent container when pressed.
 *
 * @version 99/07/10
 * @author Martin Lippert
 * @see GuiSerializer
 */
public class GuiSerializerButton extends Button implements GuiInvisible
{
	/**
	 * Create a serializer button labeled <em>Serialize...</em>.
	 */
	public GuiSerializerButton() {
		this("Serialize...");
	}
	
	/**
	 * Create a serializer button.
	 *
	 * @param label A string label for the button.
	 */
	public GuiSerializerButton(String text) {
		super(text);
		addActionListener(new ActionListener() {
		        public void actionPerformed(ActionEvent e) {
		            saveComponent();
		        }
		});
	}
	
	/**
	 * Serialize the parent container to a file. The file is questioned from the user.
	 */
	public void saveComponent() {
	    Container component = this.getParent();
	
	    Frame frame = new Frame();
	    FileDialog fd = new FileDialog(frame, "Serialize Component into File", FileDialog.SAVE);
	    // FilenameFilter filter = fd.getFilenameFilter();
	    // filter.accept(new File("."), "*.ser");
	    // fd.setFilenameFilter(filter);
	    fd.show();
	    
	    String fname = fd.getFile();
	    if (fname == null) {
            return;
	    }
	    String dname = fd.getDirectory();
	
	    // Check for name convention <Name>.ser and correct if necessary
	    if (!fname.endsWith(".ser")) {
			fname = fname + ".ser";
	    }
	
	    try {
			GuiSerializer.write(dname + fname, component);
	    }
	    catch (Exception ex) {
			System.out.println ("Serialization of component failed: " + ex);
	    }
	}
}
 