/**
 * @(#)GuiSerializerButtonBeanInfo.java
 *
 * This file belongs to the Tools and Materials Application Framework for Java.
 * Read file $JWAM/doc/Copyright about permission to use. This file may only be used
 * and distributed together with the copyright file.
 *
 * @history
 * @modification v0.10, 97/08/01, Martin Lippert
 *  Coding
 * @modification v0.11, 98/04/02, Martin Lippert
 *  renaming of packages according to JWAM 1.1
 * @modification v0.12, 99/02/12, Martin Lippert
 *  icon test implemented
 * @modification 99/02/18, Martin Lippert
 *  comments added and modified
 * @modification 99/07/10, Bernhard Fischer
 *  comments added
 */

package gui;

import java.awt.Image;

import java.beans.BeanInfo;
import java.beans.SimpleBeanInfo;
import java.beans.BeanDescriptor;

import gui.GuiSerializerButton;
import gui.GuiSerializerButtonCustomizer;


/**
 * This class implements a simple BeanInfo class for the specific
 * presentation form widget to support icons for the presentation
 * forms displayed in the IDE user interface builder palette.
 * (supporting the JavaBeans specification)
 *
 * @version 99/07/10
 * @author Martin Lippert
 * @see GuiSerializerButton
 */
public class GuiSerializerButtonBeanInfo extends SimpleBeanInfo {
    /**
     * Returns the specific BeanDescriptor to tell the IDE, that this JavaBean
     * has a specific customizer.
     *
     * @return the BeanDescriptor for
     */
    public BeanDescriptor getBeanDescriptor() {
	    BeanDescriptor bd = new BeanDescriptor(GuiSerializerButton.class, GuiSerializerButtonCustomizer.class);
	    bd.setDisplayName("GuiSerializerButton");
	    return bd;
    }


    /**
     * Returns the icon for the specific icon type.
     *
     * @param iconKind the icon kind which is supported by the IDE
     * @return the icon for the bean
     */
	public Image getIcon (int iconKind) {
		Image img = null;
		switch(iconKind) {
		case BeanInfo.ICON_COLOR_16x16:
			img = loadImage("images/GuiSerializerButtonColor16.gif");
			break;
		case BeanInfo.ICON_COLOR_32x32:
			img = loadImage("images/GuiSerializerButtonColor32.gif");
			break;
		case BeanInfo.ICON_MONO_16x16:
			img = loadImage("images/GuiSerializerButtonMono32.gif");
			break;
		case BeanInfo.ICON_MONO_32x32:
			img = loadImage("images/GuiSerializerButtonMono32.gif");
			break;
		}
		return img;
	}
}
